@@ -1,9 +1,21 @@
 from vectorcode.subcommands.check import check
+from vectorcode.subcommands.clean import clean
 from vectorcode.subcommands.drop import drop
 from vectorcode.subcommands.init import init
 from vectorcode.subcommands.ls import ls
+from vectorcode.subcommands.prompt import prompts
 from vectorcode.subcommands.query import query
 from vectorcode.subcommands.update import update
 from vectorcode.subcommands.vectorise import vectorise
 
-__all__ = ["drop", "init", "query", "ls", "vectorise", "check", "update"]
+__all__ = [
+    "drop",
+    "init",
+    "query",
+    "ls",
+    "vectorise",
+    "check",
+    "update",
+    "clean",
+    "prompts",
+]
